@@ -4,8 +4,8 @@ use Tk ();
 use Tk::Toplevel;
 
 use vars qw($VERSION $DIST_VERSION @ISA);
-$VERSION = substr(q$Revision: 2.34 $, 10) + 2 . "";
-$DIST_VERSION = "0.9927";
+$VERSION = substr(q$Revision: 2.37 $, 10) + 2 . "";
+$DIST_VERSION = "0.9928";
 
 @ISA = qw(Tk::Toplevel);
 
@@ -196,6 +196,10 @@ EOF
     ($ENV{'TKPODDEBUG'}
      ? ('-',
 	[Button => 'WidgetDump', -command => sub { $w->WidgetDump }],
+	(defined &Tk::App::Reloader::reload_new_modules
+	 ? [Button => 'Reloader', -command => sub { Tk::App::Reloader::reload_new_modules() }]
+	 : ()
+	),
        )
      : ()
     ),
@@ -318,28 +322,13 @@ sub openpod {
 	$t->destroy;
     }
 
-    my %pod_args = ('-file' => $pod);
-    if (defined $pod && $pod =~ /^-(f|q)\s+(.+)/) {
+    my %pod_args;
+    if (defined $pod && $pod =~ /^(-[fq])\s+(.+)/) {
 	my $switch = $1;
 	my $func = $2;
-	my $func_pod = "";
-	open(FUNCPOD, "-|") or do {
-	    exec "perldoc", "-u", "-$switch", $func;
-	    warn "Can't execute perldoc: $!";
-	    CORE::exit(1);
-	};
-	local $/ = undef;
-	$func_pod = join "", <FUNCPOD>;
-	close FUNCPOD;
-	if ($func_pod ne "") {
-	    delete $pod_args{'-file'};
-	    $pod_args{'-text'}  = $func_pod;
-	    if ($switch eq "f") {
-		$pod_args{'-title'} = "Function $func";
-	    } else {
-		$pod_args{'-title'} = "FAQ $func";
-	    }
-	}
+	%pod_args = $cw->getpodargs($switch, $func);
+    } else {
+	%pod_args = $cw->getpodargs($pod);
     }
 
     if (defined $pod && $pod ne "") {
@@ -355,6 +344,35 @@ sub openpod {
     }
 }
 
+sub getpodargs {
+    my($cw, @args) = @_;
+    my @pod_args;
+    if (@args == 1) {
+	@pod_args = ('-file' => $args[0]);
+    } elsif (@args == 2 && $args[0] =~ /^-([fq])$/) {
+	my $switch = $1;
+	my $func = $args[1];
+	my $func_pod = "";
+	open(FUNCPOD, "-|") or do {
+	    exec "perldoc", "-u", "-$switch", $func;
+	    warn "Can't execute perldoc: $!";
+	    CORE::exit(1);
+	};
+	local $/ = undef;
+	$func_pod = join "", <FUNCPOD>;
+	close FUNCPOD;
+	if ($func_pod ne "") {
+	    push @pod_args, '-text' => $func_pod;
+	    if ($switch eq "f") {
+		push @pod_args, '-title' => "Function $func";
+	    } else {
+		push @pod_args, '-title' => "FAQ $func";
+	    }
+	}
+    }
+    @pod_args;
+}
+
 sub newwindow {
     my($cw) = @_;
     $cw->MainWindow->Pod('-tree' => $cw->cget(-tree),
